@@ -34,7 +34,7 @@
 #' 
 .importInputTS <- function(area, timeStep, opts, fileNamePattern, colnames, 
                            inputTimeStep, fun = "sum", type = "simple", colSelect = NULL, ...) {
-
+  
   path <- file.path(opts$inputPath, sprintf(fileNamePattern, area))
   
   # if(!is.null(colSelect)){
@@ -109,9 +109,9 @@
     clusters <- list.files(file.path(opts$inputPath, "thermal/series", area))
   } else {
     clusters <- names(read_secure_json(file.path(opts$inputPath, "thermal/series", area), 
-                                 token = opts$token, timeout = opts$timeout, config = opts$httr_config))
+                                       token = opts$token, timeout = opts$timeout, config = opts$httr_config))
   }
-
+  
   ldply(clusters, function(cl) {
     filePattern <- sprintf("%s/%s/%%s/series.txt", "thermal/series", area)
     res <- .importInputTS(cl, timeStep, opts, filePattern, "ThermalAvailabilities",
@@ -128,7 +128,7 @@
 }
 
 .importResProduction <- function(area, timeStep, opts, ...) {
-
+  
   if (!area %in% opts$areasWithResClusters) return(NULL)
   
   if(!"api" %in% opts$typeLoad){
@@ -137,7 +137,7 @@
     clusters <- names(read_secure_json(file.path(opts$inputPath, "renewables/series", area), 
                                        token = opts$token, timeout = opts$timeout, config = opts$httr_config))
   }
-
+  
   ldply(clusters, function(cl) {
     filePattern <- sprintf("%s/%s/%%s/series.txt", "renewables/series", area)
     res <- .importInputTS(cl, timeStep, opts, filePattern, "production",
@@ -237,7 +237,9 @@
 }
 
 .importLinkCapacity <- function(link, timeStep, opts, unselect = NULL, ...) {
-
+  
+  
+  
   areas <- strsplit(link, " - ")[[1]]
   
   unselect <- unselect$links
@@ -245,10 +247,22 @@
   #TODO DEL after some antaresVersion, by example, del this check after Antares
   #version 8 and check in readAntares the version
   if (opts$antaresVersion >= 650) {
-    beginName <- c("transCapacityDirect", "transCapacityIndirect",
-                   "hurdlesCostDirect", "hurdlesCostIndirect",
-                   "impedances", "loopFlow", "p.ShiftMin", "p.ShiftMax")
-    fun = c("sum", "sum", "mean", "mean", "mean", "sum", "sum", "sum")
+    
+    if (opts$antaresVersion >= 820) {
+      
+      beginName <- c("hurdlesCostDirect", "hurdlesCostIndirect",
+                     "impedances", "loopFlow", "p.ShiftMin", "p.ShiftMax")
+      fun = c("mean", "mean", "mean", "sum", "sum", "sum")
+      
+    }else{
+      
+      beginName <- c("transCapacityDirect", "transCapacityIndirect",
+                     "hurdlesCostDirect", "hurdlesCostIndirect",
+                     "impedances", "loopFlow", "p.ShiftMin", "p.ShiftMax")
+      fun = c("sum", "sum", "mean", "mean", "mean", "sum", "sum", "sum")
+      
+    }
+    
   } else {
     beginName <- c("transCapacityDirect", "transCapacityIndirect",
                    "impedances", "hurdlesCostDirect", "hurdlesCostIndirect")
@@ -263,12 +277,45 @@
     names <- beginName
   }
   
-  # A bit hacky, but it works !
-  res <- .importInputTS(areas[2], timeStep, opts, 
-                        sprintf("%s/%%s.txt", file.path("links", areas[1])), 
-                        colnames=names,
-                        inputTimeStep = "hourly", 
-                        fun = fun, colSelect = colSelect)
+  
+  if(opts$antaresVersion >= 820){
+    #For V>8.2 read  transCapacityDirect in separated file, include MC
+    if(!link%in%opts$linkList)return(NULL)
+    ###Read parameters file
+      res <- .importInputTS(areas[2], timeStep, opts, 
+                            sprintf("%s/%%s_parameters.txt", file.path("links", areas[1])), 
+                            colnames = names,
+                            inputTimeStep = "hourly", 
+                            fun = fun, colSelect = colSelect)
+      
+      
+      ###Read transCapacityDirect file
+      transCapacityDirect <- .importInputTS(areas[2], timeStep, opts, 
+                                            sprintf("%s/capacities/%%s_direct.txt", file.path("links", areas[1])), 
+                                            colnames = "transCapacityDirect",
+                                            inputTimeStep = "hourly", type = "matrix",
+                                            fun = "sum", colSelect = colSelect)
+      
+      ###Read transCapacityIndirect file
+      transCapacityIndirect <- .importInputTS(areas[2], timeStep, opts, 
+                                              sprintf("%s/capacities/%%s_indirect.txt", file.path("links", areas[1])), 
+                                              colnames = "transCapacityIndirect",
+                                              inputTimeStep = "hourly", type = "matrix",
+                                              fun = "sum", colSelect = colSelect)
+      res <- merge(transCapacityIndirect, res,  by = c("area","timeId"))
+      res <- merge(transCapacityDirect, res, by = c("area","timeId", "tsId"))
+      res <- res[order(area, tsId, timeId)]
+      names <- c("tsId", "transCapacityDirect", "transCapacityIndirect", names)
+
+  }else{
+    
+    # A bit hacky, but it works !
+    res <- .importInputTS(areas[2], timeStep, opts, 
+                          sprintf("%s/%%s.txt", file.path("links", areas[1])), 
+                          colnames = names,
+                          inputTimeStep = "hourly", 
+                          fun = fun, colSelect = colSelect)
+  }
   
   res$area <- NULL
   res$link <- link
@@ -330,3 +377,4 @@
 #   out <- sub(pattern = "studies", "file", path)
 #   out <- gsub(" ", "%20", out)
 # }
+
