@@ -598,8 +598,46 @@ readAntares <- function(areas = NULL, links = NULL, clusters = NULL,
   }
   
   if (linkCapacity) {
-    .addOutputToRes("linkCapacity", links, .importLinkCapacity, NA)
-    res$links <- merge(res$links, res$linkCapacity, by=c("link", "timeId"))
+    .addOutputToRes("linkCapacity", links, .importLinkCapacity, timeStep)
+    
+    if(opts$antaresVersion>=820){
+      
+      
+      
+      if("tsId"%in%names(res$linkCapacity)){
+        if(!file.exists(file.path(opts$simDataPath, "..", "ts-numbers"))){
+          stop("Times-Series not found in output, exchange capacities can't be load")
+        }else{
+
+          ntc_build <- .getNtcOutputTs(opts)
+          res$linkCapacity <- merge(res$linkCapacity, ntc_build, allow.cartesian = TRUE)
+          res$linkCapacity[, tsId  := NULL]
+          
+          
+          if(synthesis == TRUE){
+            res$linkCapacity <- res$linkCapacity[,
+                                                 lapply(.SD, mean),
+                                                 by = c("link","timeId"),
+                                                 .SDcols = names(res$linkCapacity)[!names(res$linkCapacity)%in%c("link","timeId","mcYear")]]
+            
+            
+            
+            res$links <- merge(res$links, res$linkCapacity, by=c("link", "timeId"))
+          }else{
+            
+            res$links <- merge(res$links, res$linkCapacity, by=c("link", "timeId", "mcYear"))
+            
+            
+          }
+          
+          
+        }
+        
+      }
+    }else{
+      res$links <- merge(res$links, res$linkCapacity, by=c("link", "timeId"))
+    }
+    
     res$linkCapacity <- NULL
   }
   
@@ -718,12 +756,18 @@ readAntaresAreas <- function(areas, links = TRUE, clusters = TRUE, clustersRes =
   
   if (missing(areas)) stop("The function 'readAntaresAreas' expects a vector of area names as argument. You can use 'getAreas' to build such a vector.")
   
+  
+  ##Add check control for all
+  areas <- .checkArg(areas, opts$areaList, "Areas %s do not exist in the simulation.")
+  
   if(opts$antaresVersion < 810) clustersRes <- FALSE
   
   links <- if (links) getLinks(areas, internalOnly=internalOnly, opts = opts) else NULL
   clusters <- if(clusters) areas else NULL
   clustersRes <- if(clustersRes) areas else NULL
   
+  
+  
   readAntares(areas = areas, links = links, clusters = clusters, 
               clustersRes = clustersRes, opts = opts, ...)
   
